==> qtjambi-webenginecore-debuginfo-windows-x64-6.5.5.jar: sources/QtJambiWebEngineCore/QWebEnginePage_shell.h <==
#ifndef QWEBENGINEPAGE_SHELL_H
#define QWEBENGINEPAGE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebEngineCore/qwebenginepage.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qstring.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qcolor.h>
#include <QtGui/qicon.h>
#include <QtGui/qpagelayout.h>
#include <QtGui/qpageranges.h>
#include <QtJambi/JObjectWrapper>
#include <QtJambi/JavaAPI>
#include <QtNetwork/qauthenticator.h>
#include <QtWebChannel/qwebchannel.h>
#include <QtWebEngineCore/QWebEngineFileSystemAccessRequest>
#include <QtWebEngineCore/qwebenginecertificateerror.h>
#include <QtWebEngineCore/qwebengineclientcertificateselection.h>
#include <QtWebEngineCore/qwebenginedownloadrequest.h>
#include <QtWebEngineCore/qwebenginefilesystemaccessrequest.h>
#include <QtWebEngineCore/qwebenginefindtextresult.h>
#include <QtWebEngineCore/qwebenginefullscreenrequest.h>
#include <QtWebEngineCore/qwebenginehistory.h>
#include <QtWebEngineCore/qwebenginehttprequest.h>
#include <QtWebEngineCore/qwebengineloadinginfo.h>
#include <QtWebEngineCore/qwebenginenavigationrequest.h>
#include <QtWebEngineCore/qwebenginenewwindowrequest.h>
#include <QtWebEngineCore/qwebengineprofile.h>
#include <QtWebEngineCore/qwebenginequotarequest.h>
#include <QtWebEngineCore/qwebengineregisterprotocolhandlerrequest.h>
#include <QtWebEngineCore/qwebenginescriptcollection.h>
#include <QtWebEngineCore/qwebenginesettings.h>
#include <QtWebEngineCore/qwebengineurlrequestinterceptor.h>
#include <QtJambi/RegistryAPI>


class QWebEnginePage_shell : public QWebEnginePage, public QtJambiShellInterface
{
public:
    QWebEnginePage_shell(QObject* parent0 = nullptr);
    QWebEnginePage_shell(QWebEngineProfile* profile0, QObject* parent1 = nullptr);
    ~QWebEnginePage_shell() override;

    bool acceptNavigationRequest(const QUrl& url0, QWebEnginePage::NavigationType type1, bool isMainFrame2) override;
    void childEvent(QChildEvent* event0) override;
    QStringList chooseFiles(QWebEnginePage::FileSelectionMode mode0, const QStringList& oldFiles1, const QStringList& acceptedMimeTypes2) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QWebEnginePage* createWindow(QWebEnginePage::WebWindowType type0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void javaScriptAlert(const QUrl& securityOrigin0, const QString& msg1) override;
    bool javaScriptConfirm(const QUrl& securityOrigin0, const QString& msg1) override;
    void javaScriptConsoleMessage(QWebEnginePage::JavaScriptConsoleMessageLevel level0, const QString& message1, int lineNumber2, const QString& sourceID3) override;
    bool javaScriptPrompt(const QUrl& securityOrigin0, const QString& msg1, const QString& defaultValue2, QString* result3) override;
    void timerEvent(QTimerEvent* event0) override;
    void triggerAction(QWebEnginePage::WebAction action0, bool checked1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebEnginePage_access : public QWebEnginePage
{
    jboolean __qt_acceptNavigationRequest_cref_QUrl_QWebEnginePage_NavigationType_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jint type1, jboolean isMainFrame2);
    jobject __qt_chooseFiles_QWebEnginePage_FileSelectionMode_cref_QStringList_cref_QStringList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0, jobject oldFiles1, jobject acceptedMimeTypes2);
    jobject __qt_createWindow_QWebEnginePage_WebWindowType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_javaScriptAlert_cref_QUrl_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID securityOrigin0, jstring msg1);
    jboolean __qt_javaScriptConfirm_cref_QUrl_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID securityOrigin0, jstring msg1);
    void __qt_javaScriptConsoleMessage_QWebEnginePage_JavaScriptConsoleMessageLevel_cref_QString_int_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint level0, jstring message1, jint lineNumber2, jstring sourceID3);
    jstring __qt_javaScriptPrompt_cref_QUrl_cref_QString_cref_QString_QString_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID securityOrigin0, jstring msg1, jstring defaultValue2);
    void __qt_triggerAction_QWebEnginePage_WebAction_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint action0, jboolean checked1);
};

#endif // QWEBENGINEPAGE_SHELL_H

==> qtjambi-webenginecore-debuginfo-windows-x64-6.7.1.jar: sources/QtJambiWebEngineCore/QWebEnginePage_shell.h <==
#ifndef QWEBENGINEPAGE_SHELL_H
#define QWEBENGINEPAGE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebEngineCore/qwebenginepage.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qstring.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qcolor.h>
#include <QtGui/qicon.h>
#include <QtGui/qpagelayout.h>
#include <QtGui/qpageranges.h>
#include <QtJambi/JObjectWrapper>
#include <QtJambi/JavaAPI>
#include <QtNetwork/qauthenticator.h>
#include <QtWebChannel/qwebchannel.h>
#include <QtWebEngineCore/QWebEngineFileSystemAccessRequest>
#include <QtWebEngineCore/qwebenginecertificateerror.h>
#include <QtWebEngineCore/qwebengineclientcertificateselection.h>
#include <QtWebEngineCore/qwebenginedesktopmediarequest.h>
#include <QtWebEngineCore/qwebenginedownloadrequest.h>
#include <QtWebEngineCore/qwebenginefilesystemaccessrequest.h>
#include <QtWebEngineCore/qwebenginefindtextresult.h>
#include <QtWebEngineCore/qwebenginefullscreenrequest.h>
#include <QtWebEngineCore/qwebenginehistory.h>
#include <QtWebEngineCore/qwebenginehttprequest.h>
#include <QtWebEngineCore/qwebengineloadinginfo.h>
#include <QtWebEngineCore/qwebenginenavigationrequest.h>
#include <QtWebEngineCore/qwebenginenewwindowrequest.h>
#include <QtWebEngineCore/qwebengineprofile.h>
#include <QtWebEngineCore/qwebenginequotarequest.h>
#include <QtWebEngineCore/qwebengineregisterprotocolhandlerrequest.h>
#include <QtWebEngineCore/qwebenginescriptcollection.h>
#include <QtWebEngineCore/qwebenginesettings.h>
#include <QtWebEngineCore/qwebengineurlrequestinterceptor.h>
#include <QtWebEngineCore/qwebenginewebauthuxrequest.h>
#include <QtJambi/RegistryAPI>


class QWebEnginePage_shell : public QWebEnginePage, public QtJambiShellInterface
{
public:
    QWebEnginePage_shell(QObject* parent0 = nullptr);
    QWebEnginePage_shell(QWebEngineProfile* profile0, QObject* parent1 = nullptr);
    ~QWebEnginePage_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QWebEnginePage_mshell;
    friend class QWebEnginePage_oshell;
};


class QWebEnginePage_mshell : public QWebEnginePage_shell
{
public:
    using QWebEnginePage_shell::QWebEnginePage_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QWebEnginePage_oshell : public QWebEnginePage_mshell
{
public:
    using QWebEnginePage_mshell::QWebEnginePage_mshell;
    bool acceptNavigationRequest(const QUrl& url0, QWebEnginePage::NavigationType type1, bool isMainFrame2) override;
    void childEvent(QChildEvent* event0) override;
    QStringList chooseFiles(QWebEnginePage::FileSelectionMode mode0, const QStringList& oldFiles1, const QStringList& acceptedMimeTypes2) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QWebEnginePage* createWindow(QWebEnginePage::WebWindowType type0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void javaScriptAlert(const QUrl& securityOrigin0, const QString& msg1) override;
    bool javaScriptConfirm(const QUrl& securityOrigin0, const QString& msg1) override;
    void javaScriptConsoleMessage(QWebEnginePage::JavaScriptConsoleMessageLevel level0, const QString& message1, int lineNumber2, const QString& sourceID3) override;
    bool javaScriptPrompt(const QUrl& securityOrigin0, const QString& msg1, const QString& defaultValue2, QString* result3) override;
    void timerEvent(QTimerEvent* event0) override;
    void triggerAction(QWebEnginePage::WebAction action0, bool checked1) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebEnginePage_access : public QWebEnginePage
{
    jboolean __qt_acceptNavigationRequest_cref_QUrl_QWebEnginePage_NavigationType_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jint type1, jboolean isMainFrame2);
    jobject __qt_chooseFiles_QWebEnginePage_FileSelectionMode_cref_QStringList_cref_QStringList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0, jobject oldFiles1, jobject acceptedMimeTypes2);
    jobject __qt_createWindow_QWebEnginePage_WebWindowType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_javaScriptAlert_cref_QUrl_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID securityOrigin0, jstring msg1);
    jboolean __qt_javaScriptConfirm_cref_QUrl_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID securityOrigin0, jstring msg1);
    void __qt_javaScriptConsoleMessage_QWebEnginePage_JavaScriptConsoleMessageLevel_cref_QString_int_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint level0, jstring message1, jint lineNumber2, jstring sourceID3);
    jstring __qt_javaScriptPrompt_cref_QUrl_cref_QString_cref_QString_QString_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID securityOrigin0, jstring msg1, jstring defaultValue2);
    void __qt_triggerAction_QWebEnginePage_WebAction_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint action0, jboolean checked1);
};

#endif // QWEBENGINEPAGE_SHELL_H
